Class: BoostStyles::Generators::InstallGenerator
- Inherits:
-
Rails::Generators::Base
- Object
- Rails::Generators::Base
- BoostStyles::Generators::InstallGenerator
- Defined in:
- lib/generators/boost_styles/install_generator.rb
Instance Method Summary collapse
- #create_config_file ⇒ Object
- #create_eslint_file ⇒ Object
- #create_haml_lint_file ⇒ Object
- #create_stylelint_file ⇒ Object
- #print_instructions ⇒ Object
Instance Method Details
#create_config_file ⇒ Object
11 12 13 14 |
# File 'lib/generators/boost_styles/install_generator.rb', line 11 def create_config_file file_method = config_file_exists? ? :prepend : :create send :"#{file_method}_file", config_file_path, config_file_content end |
#create_eslint_file ⇒ Object
31 32 33 34 35 36 37 |
# File 'lib/generators/boost_styles/install_generator.rb', line 31 def create_eslint_file return unless yes?('Do you want ESLint?') return if eslint_file_exists? run('yarn add eslint') create_file(eslint_file_path, eslint_file_content) end |
#create_haml_lint_file ⇒ Object
24 25 26 27 28 29 |
# File 'lib/generators/boost_styles/install_generator.rb', line 24 def create_haml_lint_file return unless yes?('Do you want HAML lint?') return if haml_lint_file_exists? create_file(haml_lint_file_path, haml_lint_file_content) end |
#create_stylelint_file ⇒ Object
16 17 18 19 20 21 22 |
# File 'lib/generators/boost_styles/install_generator.rb', line 16 def create_stylelint_file return unless yes?('Do you want stylelint?') return if stylelint_file_exists? run('yarn add stylelint stylelint-config-standard') create_file(stylelint_file_path, stylelint_file_content) end |
#print_instructions ⇒ Object
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/generators/boost_styles/install_generator.rb', line 39 def print_instructions say " -----------------------------------------\n \u{1F389} All done! \u{1F389}\n\n Run rubocop in parallel to check the offenses:\n -> rubocop -P\n To fix the offenses, run:\n -> rubocop -a\n To generate todo, run:\n -> rubocop --auto-gen-config\n\n Run stylelint to check the offenses:\n -> stylelint --color app/assets/stylesheets/\n To fix the offenses, run:\n -> stylelint --color --fix app/assets/stylesheets/\n\n Run haml_lint to check the offenses:\n -> bundle exec haml-lint app/**/*.html.haml\n To fix the offenses, you need to diy\n -----------------------------------------\n TXT\nend\n".strip_heredoc |